==> haskell-monad-control-1.0.2.3-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-control
version:              1.0.2.3
visibility:           public
id:                   monad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd
key:                  monad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd
license:              BSD-3-Clause
copyright:            (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/monad-control
synopsis:
    Lift control operations, like exception catching, through monad transformers

description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.

    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.

    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.

category:             Control
abi:                  c3efe868cd8f2a95445a71a0a2ba4fd6
exposed:              True
exposed-modules:      Control.Monad.Trans.Control
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-control-1.0.2.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-control-1.0.2.3
hs-libraries:         HSmonad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd
depends:
    base-4.14.1.0 stm-2.5.0.0 transformers-0.5.6.2
    transformers-base-0.4.5.2-CjQNf7cAS4OKmJApB9SWyv
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:
    /usr/share/doc/haskell-monad-control/html/monad-control.haddock

haddock-html:         /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.2.3-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-control
version:              1.0.2.3
visibility:           public
id:                   monad-control-1.0.2.3-6lvq3z5h7GHAFcRjZSo9jW
key:                  monad-control-1.0.2.3-6lvq3z5h7GHAFcRjZSo9jW
license:              BSD-3-Clause
copyright:            (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/monad-control
synopsis:
    Lift control operations, like exception catching, through monad transformers

description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.

    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.

    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.

category:             Control
abi:                  a81904efb1fb505918e3b393cd558c40
exposed:              True
exposed-modules:      Control.Monad.Trans.Control
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-control-1.0.2.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-control-1.0.2.3
hs-libraries:         HSmonad-control-1.0.2.3-6lvq3z5h7GHAFcRjZSo9jW
depends:
    base-4.14.1.0 stm-2.5.0.0 transformers-0.5.6.2
    transformers-base-0.4.5.2-DzXjZ5CfVb1lHNZjOwgmR
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:
    /usr/share/doc/haskell-monad-control/html/monad-control.haddock

haddock-html:         /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
